CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
69 lines
2.3 KiB
Common Lisp
69 lines
2.3 KiB
Common Lisp
// REQUIRES: amdgpu-registered-target
|
|
// RUN: %clang_cc1 -cl-std=CL2.0 -O0 -triple amdgcn-unknown-unknown -target-cpu hawaii -emit-llvm -o - %s | FileCheck %s
|
|
// RUN: %clang_cc1 -cl-std=CL2.0 -O0 -triple amdgcn-unknown-unknown -target-cpu fiji -emit-llvm -o - %s | FileCheck %s
|
|
// RUN: %clang_cc1 -cl-std=CL2.0 -O0 -triple amdgcn-unknown-unknown -target-cpu gfx906 -emit-llvm -o - %s | FileCheck %s
|
|
// RUN: %clang_cc1 -cl-std=CL2.0 -O0 -triple amdgcn-unknown-unknown -target-cpu gfx1010 -emit-llvm -o - %s | FileCheck %s
|
|
|
|
typedef unsigned int uint;
|
|
typedef unsigned long ulong;
|
|
|
|
// CHECK-LABEL: @test_s_dcache_inv_vol
|
|
// CHECK: call void @llvm.amdgcn.s.dcache.inv.vol(
|
|
void test_s_dcache_inv_vol()
|
|
{
|
|
__builtin_amdgcn_s_dcache_inv_vol();
|
|
}
|
|
|
|
// CHECK-LABEL: @test_buffer_wbinvl1_vol
|
|
// CHECK: call void @llvm.amdgcn.buffer.wbinvl1.vol()
|
|
void test_buffer_wbinvl1_vol()
|
|
{
|
|
__builtin_amdgcn_buffer_wbinvl1_vol();
|
|
}
|
|
|
|
// CHECK-LABEL: @test_gws_sema_release_all(
|
|
// CHECK: call void @llvm.amdgcn.ds.gws.sema.release.all(i32 %{{[0-9]+}})
|
|
void test_gws_sema_release_all(uint id)
|
|
{
|
|
__builtin_amdgcn_ds_gws_sema_release_all(id);
|
|
}
|
|
|
|
// CHECK-LABEL: @test_s_memtime
|
|
// CHECK: call i64 @llvm.amdgcn.s.memtime()
|
|
void test_s_memtime(global ulong* out)
|
|
{
|
|
*out = __builtin_amdgcn_s_memtime();
|
|
}
|
|
|
|
// CHECK-LABEL: @test_is_shared(
|
|
// CHECK: call i1 @llvm.amdgcn.is.shared(ptr %{{[0-9]+}}
|
|
int test_is_shared(const int* ptr) {
|
|
return __builtin_amdgcn_is_shared(ptr);
|
|
}
|
|
|
|
// CHECK-LABEL: @test_is_private(
|
|
// CHECK: call i1 @llvm.amdgcn.is.private(ptr %{{[0-9]+}}
|
|
int test_is_private(const int* ptr) {
|
|
return __builtin_amdgcn_is_private(ptr);
|
|
}
|
|
|
|
// CHECK-LABEL: @test_is_shared_global(
|
|
// CHECK: [[CAST:%[0-9]+]] = addrspacecast ptr addrspace(1) %{{[0-9]+}} to ptr
|
|
// CHECK: call i1 @llvm.amdgcn.is.shared(ptr [[CAST]]
|
|
int test_is_shared_global(const global int* ptr) {
|
|
return __builtin_amdgcn_is_shared(ptr);
|
|
}
|
|
|
|
// CHECK-LABEL: @test_is_private_global(
|
|
// CHECK: [[CAST:%[0-9]+]] = addrspacecast ptr addrspace(1) %{{[0-9]+}} to ptr
|
|
// CHECK: call i1 @llvm.amdgcn.is.private(ptr [[CAST]]
|
|
int test_is_private_global(const global int* ptr) {
|
|
return __builtin_amdgcn_is_private(ptr);
|
|
}
|
|
|
|
// CHECK-LABEL: @test_groupstaticsize
|
|
// CHECK: call i32 @llvm.amdgcn.groupstaticsize()
|
|
void test_groupstaticsize(global uint* out) {
|
|
*out = __builtin_amdgcn_groupstaticsize();
|
|
}
|